@@ -30,7 +30,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '3.0';
+our $VERSION = '3.01';
 
 sub db { $_[0]->database_class->new(dbh => $_[0]->_dequeue, pg => $_[0]) }
 
@@ -131,38 +131,27 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
   $db->update('names', {name => 'Bel'}, {name => 'Isabel'});
   $db->delete('names', {name => 'Bel'});
 
-  # Insert a few rows
-  $db->query('insert into names (name) values (?)', 'Sara');
-  $db->query('insert into names (name) values (?)', 'Stefan');
-
-  # Insert more rows in a transaction
+  # Insert a few rows in a transaction with SQL and placeholders
   eval {
     my $tx = $db->begin;
-    $db->query('insert into names (name) values (?)', 'Baerbel');
-    $db->query('insert into names (name) values (?)', 'Wolfgang');
+    $db->query('insert into names (name) values (?)', 'Sara');
+    $db->query('insert into names (name) values (?)', 'Stefan');
     $tx->commit;
   };
   say $@ if $@;
 
-  # Insert another row and return the generated id
-  say $db->query('insert into names (name) values (?) returning id', 'Daniel')
-    ->hash->{id};
+  # Insert another row with SQL::Abstract and return the generated id
+  say $db->insert('names', {name => 'Daniel'}, {returning => 'id'})->hash->{id};
 
   # JSON roundtrip
   say $db->query('select ?::json as foo', {json => {bar => 'baz'}})
     ->expand->hash->{foo}{bar};
 
-  # Select one row at a time
-  my $results = $db->query('select * from names');
-  while (my $next = $results->hash) {
-    say $next->{name};
-  }
+  # Select all rows blocking with SQL::Abstract
+  say $_->{name} for $db->select('names')->hashes->each;
 
-  # Select all rows blocking
-  say $_->{name} for $db->query('select * from names')->hashes->each;
-
-  # Select all rows non-blocking
-  $db->query('select * from names' => sub {
+  # Select all rows non-blocking with SQL::Abstract
+  $db->select('names' => sub {
     my ($db, $err, $results) = @_;
     die $err if $err;
     say $_->{name} for $results->hashes->each;
@@ -315,8 +304,8 @@ L<Mojo::Pg> implements the following attributes.
 
 L<SQL::Abstract> object used to generate CRUD queries for L<Mojo::Pg::Database>.
 
-  # Generate statements and bind values
-  my($stmt, @bind) = $pg->abstract->select('names');
+  # Generate WHERE clause and bind values
+  my($stmt, @bind) = $pg->abstract->where({foo => 'bar', baz => 'yada'});
 
 =head2 auto_migrate
 
@@ -424,11 +413,11 @@ following new ones.
 
   my $db = $pg->db;
 
-Get a database object based on L</"database_class"> for a cached or newly
-established database connection. The L<DBD::Pg> database handle will be
-automatically cached again when that object is destroyed, so you can handle
-problems like connection timeouts gracefully by holding on to it only for short
-amounts of time.
+Get a database object based on L</"database_class"> (which is usually
+L<Mojo::Pg::Database>) for a cached or newly established database connection.
+The L<DBD::Pg> database handle will be automatically cached again when that
+object is destroyed, so you can handle problems like connection timeouts
+gracefully by holding on to it only for short amounts of time.
 
   # Add up all the money
   say $pg->db->select('accounts')
