@@ -14,7 +14,7 @@ has [qw(dbh pg)];
 has results_class => 'Mojo::Pg::Results';
 
 for my $name (qw(delete insert select update)) {
-  monkey_patch __PACKAGE__, lc $name, sub {
+  monkey_patch __PACKAGE__, $name, sub {
     my ($self, @cb) = (shift, ref $_[-1] eq 'CODE' ? pop : ());
     return $self->query($self->pg->abstract->$name(@_), @cb);
   };
@@ -275,6 +275,18 @@ callback to perform operations non-blocking.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<delete> method of
+L<SQL::Abstract>.
+
+  # "delete from some_table"
+  $db->delete('some_table');
+
+  # "delete from some_table where foo = 'bar'"
+  $db->delete('some_table', {foo => 'bar'});
+
+  # "delete from some_table where foo like '%test%'"
+  $db->delete('some_table', {foo => {-like => '%test%'}});
+
 =head2 disconnect
 
   $db->disconnect;
@@ -306,6 +318,18 @@ callback to perform operations non-blocking.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<insert> method of
+L<SQL::Abstract>.
+
+  # "insert into some_table (foo, baz) values ('bar', 'yada')"
+  $db->insert('some_table', {foo => 'bar', baz => 'yada'});
+
+  # "insert into some_table (foo) values ('bar') returning id"
+  $db->insert('some_table', {foo => 'bar'}, {returning => 'id'});
+
+  # "insert into some_table (foo) values ('bar') returning id, foo"
+  $db->insert('some_table', {foo => 'bar'}, {returning => ['id', 'foo']});
+
 =head2 is_listening
 
   my $bool = $db->is_listening;
@@ -345,10 +369,11 @@ Check database connection.
   my $results = $db->query('select ?::json as foo', {json => {bar => 'baz'}});
 
 Execute a blocking L<SQL|http://www.postgresql.org/docs/current/static/sql.html>
-statement and return a results object based on L</"results_class"> with the
-query results. The L<DBD::Pg> statement handle will be automatically reused when
-it is not active anymore, to increase the performance of future queries. You can
-also append a callback to perform operations non-blocking.
+statement and return a results object based on L</"results_class"> (which is
+usually L<Mojo::Pg::Results>) with the query results. The L<DBD::Pg> statement
+handle will be automatically reused when it is not active anymore, to increase
+the performance of future queries. You can also append a callback to perform
+operations non-blocking.
 
   $db->query('insert into foo values (?, ?, ?)' => @values => sub {
     my ($db, $err, $results) = @_;
@@ -386,6 +411,24 @@ callback to perform operations non-blocking.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<select> method of
+L<SQL::Abstract>.
+
+  # "select * from some_table"
+  $db->select('some_table');
+
+  # "select id, foo from some_table"
+  $db->select('some_table', ['id', 'foo']);
+
+  # "select * from some_table where foo = 'bar'"
+  $db->select('some_table', undef, {foo => 'bar'});
+
+  # "select * from some_table where foo = 'bar' order by id desc"
+  $db->select('some_table', undef, {foo => 'bar'}, {-desc => 'id'});
+
+  # "select * from some_table where foo like '%test%'"
+  $db->select('some_table', undef, {foo => {-like => '%test%'}});
+
 =head2 tables
 
   my $tables = $db->tables;
@@ -417,6 +460,15 @@ callback to perform operations non-blocking.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<update> method of
+L<SQL::Abstract>.
+
+  # "update some_table set foo = 'bar' where id = 23"
+  $db->update('some_table', {foo => 'bar'}, {id => 23});
+
+  # "update some_table set foo = 'bar' where foo like '%test%'"
+  $db->update('some_table', {foo => 'bar'}, {foo => {-like => '%test%'}});
+
 =head1 SEE ALSO
 
 L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
